"use client";

// src/core/SSRProvider.tsx
import { SSRProvider as OriginSSRProvider } from "@react-aria/ssr";
import { version, Fragment } from "react";
function isReactVersionOver(minVersion) {
  const reactMajorVersion = parseInt(version.split(".")[0], 10);
  return Number.isFinite(reactMajorVersion) ? reactMajorVersion >= minVersion : false;
}
var SSRProvider = isReactVersionOver(18) ? Fragment : OriginSSRProvider;

// src/core/OverlayProvider.tsx
import { OverlayProvider } from "@react-aria/overlays";

// src/core/CharcoalProvider.tsx
import { jsx } from "react/jsx-runtime";
function CharcoalProvider({
  children
}) {
  return /* @__PURE__ */ jsx(SSRProvider, { children: /* @__PURE__ */ jsx(OverlayProvider, { children }) });
}

// src/core/themeHelper.ts
import { useEffect, useMemo, useState } from "react";
var LOCAL_STORAGE_KEY = "charcoal-theme";
var DEFAULT_ROOT_ATTRIBUTE = "theme";
var keyStringRegExp = new RegExp(/^(\w|-)+$/);
function assertKeyString(key) {
  if (!keyStringRegExp.test(key)) {
    throw new Error(`Unexpected key :${key}, expect: /^(\\w|-)+$/`);
  }
}
var themeSetter = (attr = DEFAULT_ROOT_ATTRIBUTE) => (theme) => {
  assertKeyString(attr);
  if (theme !== void 0) {
    document.documentElement.dataset[attr] = theme;
  } else {
    delete document.documentElement.dataset[attr];
  }
};
function themeSelector(theme, attr) {
  return `:root[data-${attr ?? DEFAULT_ROOT_ATTRIBUTE}='${theme}']`;
}
function prefersColorScheme(theme) {
  return `@media (prefers-color-scheme: ${theme})`;
}
function useThemeSetter({
  key = LOCAL_STORAGE_KEY,
  setter = themeSetter()
} = {}) {
  const [theme, , system] = useTheme(key);
  useEffect(() => {
    if (theme === void 0) {
      return;
    }
    setter(system ? void 0 : theme);
  }, [setter, system, theme]);
}
function getThemeSync(key = LOCAL_STORAGE_KEY) {
  const theme = localStorage.getItem(key);
  return theme;
}
var useTheme = (localStorageKey = LOCAL_STORAGE_KEY) => {
  assertKeyString(localStorageKey);
  const isDark = useMedia("(prefers-color-scheme: dark)");
  const media = isDark !== void 0 ? isDark ? "dark" : "light" : void 0;
  const [local, setTheme, ready] = useLocalStorage(localStorageKey);
  const theme = !ready || media === void 0 ? void 0 : local ?? media;
  const system = local === void 0;
  return [theme, setTheme, system];
};
function useLocalStorage(key, defaultValue) {
  const [ready, setReady] = useState(false);
  const [state, setState] = useState();
  const defaultValueMemo = useMemo(() => defaultValue?.(), [defaultValue]);
  useEffect(() => {
    fetch();
    window.addEventListener("storage", handleStorage);
    return () => {
      window.removeEventListener("storage", handleStorage);
    };
  });
  const handleStorage = (e) => {
    if (e.storageArea !== localStorage) {
      return;
    }
    if (e.key !== key) {
      return;
    }
    fetch();
  };
  const fetch = () => {
    const raw = localStorage.getItem(key);
    setState((raw !== null ? deserialize(raw) : null) ?? defaultValueMemo);
    setReady(true);
  };
  const set = (value) => {
    if (value === void 0) {
      localStorage.removeItem(key);
    } else {
      const raw = serialize(value);
      localStorage.setItem(key, raw);
    }
    const event = new StorageEvent("storage", {
      bubbles: true,
      cancelable: false,
      key,
      url: location.href,
      storageArea: localStorage
    });
    dispatchEvent(event);
  };
  return [state ?? defaultValueMemo, set, ready];
}
function deserialize(raw) {
  try {
    return JSON.parse(raw);
  } catch {
    return raw;
  }
}
function serialize(value) {
  if (typeof value === "string") {
    return value;
  } else {
    return JSON.stringify(value);
  }
}
function useMedia(query) {
  const [match, setState] = useState();
  useEffect(() => {
    const matcher = window.matchMedia(query);
    const onChange = () => {
      setState(matcher.matches);
    };
    matcher.addEventListener("change", onChange);
    setState(matcher.matches);
    return () => {
      matcher.removeEventListener("change", onChange);
    };
  }, [query]);
  return match;
}

// src/core/SetThemeScript.tsx
import { jsx as jsx2 } from "react/jsx-runtime";
function makeSetThemeScriptCode({
  localStorageKey = defaultProps.localStorageKey,
  rootAttribute = defaultProps.rootAttribute
} = defaultProps) {
  assertKeyString(localStorageKey);
  assertKeyString(rootAttribute);
  return `'use strict';
(function () {
    var localStorageKey = '${localStorageKey}'
    var rootAttribute = '${rootAttribute}'
    var currentTheme = localStorage.getItem(localStorageKey);
    if (currentTheme) {
        document.documentElement.dataset[rootAttribute] = currentTheme;
    }
})();
`;
}
function SetThemeScript({
  localStorageKey = defaultProps.localStorageKey,
  rootAttribute = defaultProps.rootAttribute
}) {
  const src = makeSetThemeScriptCode({
    localStorageKey,
    rootAttribute
  });
  return /* @__PURE__ */ jsx2("script", { dangerouslySetInnerHTML: {
    __html: src
  } });
}
var defaultProps = {
  localStorageKey: LOCAL_STORAGE_KEY,
  rootAttribute: DEFAULT_ROOT_ATTRIBUTE
};

// src/components/Button/index.tsx
import { forwardRef, useMemo as useMemo3 } from "react";

// src/_lib/useClassNames.ts
import { useMemo as useMemo2 } from "react";
function useClassNames(...classNames) {
  return useMemo2(() => classNames.filter((v) => v).join(" "), [classNames]);
}

// src/components/Button/index.tsx
import { jsx as jsx3 } from "react/jsx-runtime";
var Button = forwardRef(function Button2({
  variant,
  fullWidth,
  size,
  className,
  component,
  isActive,
  ...props
}, ref) {
  const Component = useMemo3(() => component ?? "button", [component]);
  const classNames = useClassNames("charcoal-button", className);
  return /* @__PURE__ */ jsx3(Component, { ...props, className: classNames, "data-variant": variant, "data-size": size, "data-full-width": fullWidth, "data-active": isActive, ref });
});
var Button_default = Button;

// src/components/Clickable/index.tsx
import { useMemo as useMemo4, forwardRef as forwardRef2 } from "react";
import { jsx as jsx4 } from "react/jsx-runtime";
var Clickable = forwardRef2(function Clickable2({
  component,
  ...props
}, ref) {
  const className = useClassNames("charcoal-clickable", props.className);
  const Component = useMemo4(() => component ?? "button", [component]);
  return /* @__PURE__ */ jsx4(Component, { ...props, ref, className });
});
var Clickable_default = Clickable;

// src/components/IconButton/index.tsx
import { forwardRef as forwardRef3, useMemo as useMemo5 } from "react";
import { jsx as jsx5 } from "react/jsx-runtime";
var IconButton = forwardRef3(function IconButtonInner({
  variant = "Default",
  size = "M",
  icon,
  isActive = false,
  component,
  ...rest
}, ref) {
  validateIconSize(size, icon);
  const Component = useMemo5(() => component ?? "button", [component]);
  const classNames = useClassNames("charcoal-icon-button", rest.className);
  return /* @__PURE__ */ jsx5(Component, { ...rest, ref, className: classNames, "data-size": size, "data-active": isActive, "data-variant": variant, children: /* @__PURE__ */ jsx5("pixiv-icon", { name: icon }) });
});
var IconButton_default = IconButton;
function validateIconSize(size, icon) {
  let requiredIconSize;
  switch (size) {
    case "XS":
      requiredIconSize = "16";
      break;
    case "S":
    case "M":
      requiredIconSize = "24";
      break;
  }
  const result = /^\d*/u.exec(icon);
  if (result == null) {
    throw new Error("Invalid icon name");
  }
  const [iconSize] = result;
  if (iconSize !== requiredIconSize) {
    console.warn(`IconButton with size "${size}" expect icon size "${requiredIconSize}, but got "${iconSize}"`);
  }
}

// src/components/Radio/index.tsx
import { memo as memo2, forwardRef as forwardRef5, useContext } from "react";
import warning from "warning";

// src/components/Radio/RadioGroupContext.ts
import * as React4 from "react";
var RadioGroupContext = React4.createContext({
  name: void 0,
  selected: void 0,
  disabled: false,
  readonly: false,
  invalid: false,
  onChange() {
    throw new Error("Cannot find onChange() handler. Perhaps you forgot to wrap with <RadioGroup> ?");
  }
});

// src/components/Radio/RadioInput/index.tsx
import { forwardRef as forwardRef4, memo, useCallback } from "react";
import { jsx as jsx6 } from "react/jsx-runtime";
var RadioInput = forwardRef4(function RadioInput2({
  onChange,
  invalid,
  className,
  ...props
}, ref) {
  const handleChange = useCallback((e) => {
    const el = e.currentTarget;
    onChange?.(el.value);
  }, [onChange]);
  const classNames = useClassNames("charcoal-radio-input", className);
  return /* @__PURE__ */ jsx6("input", { className: classNames, ref, type: "radio", onChange: handleChange, "aria-invalid": invalid, ...props });
});
var RadioInput_default = memo(RadioInput);

// src/components/Radio/index.tsx
import { jsx as jsx7, jsxs } from "react/jsx-runtime";
var Radio = forwardRef5(function RadioInner({
  value,
  disabled = false,
  children,
  ...props
}, ref) {
  const {
    name,
    selected,
    disabled: isParentDisabled,
    readonly,
    invalid,
    onChange
  } = useContext(RadioGroupContext);
  const classNames = useClassNames("charcoal-radio__label", props.className);
  warning(
    // eslint-disable-next-line @typescript-eslint/no-unnecessary-condition
    name !== void 0,
    `"name" is not Provided for <Radio>. Perhaps you forgot to wrap with <RadioGroup> ?`
  );
  const isSelected = value === selected;
  const isDisabled = disabled || isParentDisabled;
  const isReadonly = readonly && !isSelected;
  return /* @__PURE__ */ jsxs("label", { "aria-disabled": isDisabled || isReadonly, className: classNames, children: [
    /* @__PURE__ */ jsx7(RadioInput_default, { name, value, checked: isSelected, "aria-invalid": invalid, onChange, disabled: isDisabled || isReadonly, ref }),
    children != null && /* @__PURE__ */ jsx7("div", { className: "charcoal-radio__label_div", children })
  ] });
});
var Radio_default = memo2(Radio);

// src/components/Radio/RadioGroup/index.tsx
import { forwardRef as forwardRef6, useCallback as useCallback2, useMemo as useMemo6 } from "react";
import { jsx as jsx8 } from "react/jsx-runtime";
var RadioGroup = forwardRef6(function RadioGroupInner({
  value,
  label,
  name,
  onChange,
  disabled,
  readonly,
  invalid,
  children,
  "aria-orientation": ariaOrientation = "vertical",
  ...props
}, ref) {
  const classNames = useClassNames("charcoal-radio-group", props.className);
  const handleChange = useCallback2((next) => {
    onChange(next);
  }, [onChange]);
  const contextValue = useMemo6(() => ({
    name,
    selected: value,
    disabled: disabled ?? false,
    readonly: readonly ?? false,
    invalid: invalid ?? false,
    onChange: handleChange
  }), [disabled, handleChange, invalid, name, readonly, value]);
  return /* @__PURE__ */ jsx8(RadioGroupContext.Provider, { value: contextValue, children: /* @__PURE__ */ jsx8("div", { role: "radiogroup", "aria-disabled": disabled, "aria-invalid": invalid, "aria-label": label, "aria-labelledby": props["aria-labelledby"], "aria-orientation": ariaOrientation, className: classNames, ref, children }) });
});

// src/components/MultiSelect/index.tsx
import { useCallback as useCallback3, useContext as useContext2, forwardRef as forwardRef8, memo as memo3 } from "react";
import warning2 from "warning";

// src/components/MultiSelect/context.ts
import { createContext as createContext2 } from "react";
var MultiSelectGroupContext = createContext2({
  name: void 0,
  selected: [],
  disabled: false,
  readonly: false,
  invalid: false,
  onChange() {
    throw new Error("Cannot find `onChange()` handler. Perhaps you forgot to wrap it with `<MultiSelectGroup />` ?");
  }
});

// src/components/Icon/index.tsx
import * as React5 from "react";
import "@charcoal-ui/icons";
import { jsx as jsx9 } from "react/jsx-runtime";
var Icon = React5.forwardRef(function IconInner({
  name,
  scale,
  unsafeNonGuidelineScale,
  className,
  ...rest
}, ref) {
  return /* @__PURE__ */ jsx9("pixiv-icon", { ref, name, scale, "unsafe-non-guideline-scale": unsafeNonGuidelineScale, class: className, ...rest });
});
var Icon_default = Icon;

// src/components/MultiSelect/index.tsx
import { jsx as jsx10, jsxs as jsxs2 } from "react/jsx-runtime";
var MultiSelect = forwardRef8(function MultiSelectInner({
  value,
  disabled = false,
  onChange,
  variant = "default",
  className,
  children
}, ref) {
  const {
    name,
    selected,
    disabled: parentDisabled,
    readonly,
    invalid,
    onChange: parentOnChange
  } = useContext2(MultiSelectGroupContext);
  warning2(
    // eslint-disable-next-line @typescript-eslint/no-unnecessary-condition
    name !== void 0,
    `"name" is not Provided for <MultiSelect>. Perhaps you forgot to wrap with <MultiSelectGroup> ?`
  );
  const isSelected = selected.includes(value);
  const isDisabled = disabled || parentDisabled || readonly;
  const handleChange = useCallback3((event) => {
    if (!(event.currentTarget instanceof HTMLInputElement)) {
      return;
    }
    if (onChange)
      onChange({
        value,
        selected: event.currentTarget.checked
      });
    parentOnChange({
      value,
      selected: event.currentTarget.checked
    });
  }, [onChange, parentOnChange, value]);
  const classNames = useClassNames("charcoal-multi-select", className);
  return /* @__PURE__ */ jsxs2("label", { "aria-disabled": isDisabled, className: classNames, children: [
    /* @__PURE__ */ jsx10("input", { className: "charcoal-multi-select-input", name, value, type: "checkbox", checked: isSelected, disabled: isDisabled, onChange: handleChange, "data-overlay": variant === "overlay", "aria-invalid": invalid, ref }),
    /* @__PURE__ */ jsx10("div", { className: "charcoal-multi-select-overlay", "data-overlay": variant === "overlay", "aria-invalid": invalid, "aria-hidden": true, children: /* @__PURE__ */ jsx10(Icon_default, { name: "24/Check", "unsafe-non-guideline-scale": 16 / 24 }) }),
    Boolean(children) && /* @__PURE__ */ jsx10("div", { className: "charcoal-multi-select-label", children })
  ] });
});
var MultiSelect_default = memo3(MultiSelect);
function MultiSelectGroup({
  className,
  style,
  name,
  label,
  selected,
  onChange,
  disabled = false,
  readonly = false,
  invalid = false,
  children
}) {
  const handleChange = useCallback3((payload) => {
    const index = selected.indexOf(payload.value);
    if (payload.selected) {
      if (index < 0) {
        onChange([...selected, payload.value]);
      }
    } else {
      if (index >= 0) {
        onChange([...selected.slice(0, index), ...selected.slice(index + 1)]);
      }
    }
  }, [onChange, selected]);
  return /* @__PURE__ */ jsx10(MultiSelectGroupContext.Provider, { value: {
    name,
    selected: Array.from(new Set(selected)),
    disabled,
    readonly,
    invalid,
    onChange: handleChange
  }, children: /* @__PURE__ */ jsx10("div", { className, style, "aria-label": label, "data-testid": "SelectGroup", children }) });
}

// src/components/Switch/index.tsx
import { memo as memo5, forwardRef as forwardRef10 } from "react";
import { useId } from "@react-aria/utils";

// src/components/Switch/SwitchInput/index.tsx
import { forwardRef as forwardRef9, useCallback as useCallback4 } from "react";
import { jsx as jsx11 } from "react/jsx-runtime";
var SwitchInput = forwardRef9(function SwitchInput2({
  onChange,
  className,
  ...props
}, ref) {
  const handleChange = useCallback4((e) => {
    const el = e.currentTarget;
    onChange?.(el.checked);
  }, [onChange]);
  const classNames = useClassNames("charcoal-switch-input", className);
  return /* @__PURE__ */ jsx11("input", { ref, className: classNames, type: "checkbox", onChange: handleChange, ...props });
});
var SwitchInput_default = SwitchInput;

// src/components/Switch/SwitchWithLabel.tsx
import * as React6 from "react";
import { jsx as jsx12, jsxs as jsxs3 } from "react/jsx-runtime";
var SwitchWithLabel = React6.memo(function SwitchWithLabel2({
  children,
  className,
  disabled,
  id,
  input
}) {
  const classNames = useClassNames("charcoal-switch__label", className);
  return /* @__PURE__ */ jsxs3("label", { htmlFor: id, className: classNames, "aria-disabled": disabled, children: [
    input,
    /* @__PURE__ */ jsx12("div", { className: "charcoal-switch__label_div", children })
  ] });
});

// src/components/Switch/index.tsx
import { jsx as jsx13 } from "react/jsx-runtime";
var Switch = forwardRef10(function Switch2({
  children,
  onChange,
  disabled,
  className,
  id,
  ...props
}, ref) {
  const htmlId = useId(id);
  const noChildren = children === void 0;
  const input = /* @__PURE__ */ jsx13(SwitchInput_default, { ...props, disabled, className: noChildren ? className : void 0, id: htmlId, onChange, ref, role: "switch", type: "checkbox" });
  if (noChildren) {
    return input;
  }
  return /* @__PURE__ */ jsx13(SwitchWithLabel, { className, disabled, id: htmlId, input, children });
});
var Switch_default = memo5(Switch);

// src/components/TextField/index.tsx
import { useVisuallyHidden } from "@react-aria/visually-hidden";
import { useCallback as useCallback5, useEffect as useEffect3, useRef, useState as useState2 } from "react";
import * as React8 from "react";

// src/components/FieldLabel/index.tsx
import * as React7 from "react";
import { jsx as jsx14, jsxs as jsxs4 } from "react/jsx-runtime";
var FieldLabel = React7.forwardRef(function FieldLabel2({
  style,
  className,
  label,
  required = false,
  requiredText,
  subLabel,
  ...labelProps
}, ref) {
  const classNames = useClassNames("charcoal-field-label-root", className);
  return /* @__PURE__ */ jsxs4("div", { style, className: classNames, children: [
    /* @__PURE__ */ jsx14("label", { ref, className: "charcoal-field-label", ...labelProps, children: label }),
    required && /* @__PURE__ */ jsx14("div", { className: "charcoal-field-label-required-text", children: requiredText }),
    /* @__PURE__ */ jsx14("div", { className: "charcoal-field-label-sub-label", children: /* @__PURE__ */ jsx14("span", { children: subLabel }) })
  ] });
});
var FieldLabel_default = FieldLabel;

// src/_lib/index.ts
function mergeRefs(...refs) {
  return (value) => {
    for (const ref of refs) {
      if (typeof ref === "function") {
        ref(value);
      } else if (ref !== null) {
        ;
        ref.current = value;
      }
    }
  };
}
function countCodePointsInString(string) {
  return Array.from(string).length;
}

// src/components/TextField/useFocusWithClick.tsx
import { useEffect as useEffect2 } from "react";
function useFocusWithClick(containerRef, inputRef) {
  useEffect2(() => {
    const el = containerRef.current;
    if (el) {
      const handleDown = (e) => {
        if (e.target !== inputRef.current) {
          inputRef.current?.focus();
        }
      };
      el.addEventListener("click", handleDown);
      return () => {
        el.removeEventListener("click", handleDown);
      };
    }
  });
}

// src/components/TextField/index.tsx
import { mergeRefs as mergeRefs2, useId as useId2 } from "@react-aria/utils";

// src/_lib/createDivComponent.tsx
import { forwardRef as forwardRef12 } from "react";
import { jsx as jsx15 } from "react/jsx-runtime";
function createDivComponent(mainClassName) {
  return forwardRef12(function DivComponent({
    className,
    ...props
  }, ref) {
    const classNames = useClassNames(mainClassName, className);
    return /* @__PURE__ */ jsx15("div", { className: classNames, ref, ...props });
  });
}

// src/components/TextField/AssistiveText/index.tsx
var AssistiveText = createDivComponent("charcoal-text-field-assistive-text");

// src/components/TextField/index.tsx
import { jsx as jsx16, jsxs as jsxs5 } from "react/jsx-runtime";
var TextField = React8.forwardRef(function SingleLineTextFieldInner({
  assistiveText,
  className,
  disabled = false,
  label = "",
  maxLength,
  onChange,
  prefix = null,
  required,
  requiredText,
  showCount = false,
  showLabel = false,
  subLabel,
  suffix = null,
  type = "text",
  invalid,
  value,
  getCount = countCodePointsInString,
  ...props
}, forwardRef24) {
  const inputRef = useRef(null);
  const {
    visuallyHiddenProps
  } = useVisuallyHidden();
  const [count, setCount] = useState2(getCount(value ?? ""));
  const handleChange = useCallback5((e) => {
    const value2 = e.target.value;
    const count2 = getCount(value2);
    if (maxLength !== void 0 && count2 > maxLength) {
      return;
    }
    setCount(count2);
    onChange?.(value2);
  }, [getCount, maxLength, onChange]);
  useEffect3(() => {
    setCount(getCount(value ?? ""));
  }, [getCount, value]);
  const containerRef = useRef(null);
  useFocusWithClick(containerRef, inputRef);
  const inputId = useId2(props.id);
  const describedbyId = useId2();
  const labelledbyId = useId2();
  const showAssistiveText = assistiveText != null && assistiveText.length !== 0;
  const classNames = useClassNames("charcoal-text-field-root", className);
  return /* @__PURE__ */ jsxs5("div", { className: classNames, "aria-disabled": disabled, children: [
    /* @__PURE__ */ jsx16(FieldLabel_default, { htmlFor: inputId, id: labelledbyId, label, required, requiredText, subLabel, ...!showLabel ? visuallyHiddenProps : {} }),
    /* @__PURE__ */ jsxs5("div", { className: "charcoal-text-field-container", "aria-disabled": disabled === true ? true : void 0, "data-invalid": invalid === true, ref: containerRef, children: [
      prefix && /* @__PURE__ */ jsx16("div", { className: "charcoal-text-field-prefix", children: prefix }),
      /* @__PURE__ */ jsx16("input", { className: "charcoal-text-field-input", "aria-describedby": showAssistiveText ? describedbyId : void 0, "aria-invalid": invalid, "aria-labelledby": labelledbyId, id: inputId, "data-invalid": invalid === true, maxLength, onChange: handleChange, disabled, ref: mergeRefs2(forwardRef24, inputRef), type, value, ...props }),
      (suffix || showCount) && /* @__PURE__ */ jsxs5("div", { className: "charcoal-text-field-suffix", children: [
        suffix,
        showCount && /* @__PURE__ */ jsx16("span", { className: "charcoal-text-field-line-counter", children: maxLength !== void 0 ? `${count}/${maxLength}` : count })
      ] })
    ] }),
    showAssistiveText && /* @__PURE__ */ jsx16(AssistiveText, { "data-invalid": invalid === true, id: describedbyId, children: assistiveText })
  ] });
});
var TextField_default = TextField;

// src/components/TextArea/index.tsx
import { useVisuallyHidden as useVisuallyHidden2 } from "@react-aria/visually-hidden";
import { forwardRef as forwardRef14, useCallback as useCallback6, useEffect as useEffect4, useRef as useRef2, useState as useState3 } from "react";
import { useId as useId3 } from "@react-aria/utils";
import { jsx as jsx17, jsxs as jsxs6 } from "react/jsx-runtime";
var TextArea = forwardRef14(function TextAreaInner({
  onChange,
  className,
  value,
  showCount = false,
  showLabel = false,
  label = "",
  requiredText,
  subLabel,
  disabled = false,
  required,
  assistiveText,
  maxLength,
  autoHeight = false,
  rows: initialRows = 4,
  invalid,
  getCount = countCodePointsInString,
  ...props
}, forwardRef24) {
  const {
    visuallyHiddenProps
  } = useVisuallyHidden2();
  const textareaRef = useRef2(null);
  const [count, setCount] = useState3(getCount(value ?? ""));
  const [rows, setRows] = useState3(initialRows);
  const syncHeight = useCallback6((textarea) => {
    const rows2 = (`${textarea.value}
`.match(/\n/gu)?.length ?? 0) || 1;
    setRows(initialRows <= rows2 ? rows2 : initialRows);
  }, [initialRows]);
  const nonControlled = value === void 0;
  const handleChange = useCallback6((e) => {
    const value2 = e.target.value;
    const count2 = getCount(value2);
    if (maxLength !== void 0 && count2 > maxLength) {
      return;
    }
    if (nonControlled) {
      setCount(count2);
    }
    if (autoHeight && textareaRef.current !== null) {
      syncHeight(textareaRef.current);
    }
    onChange?.(value2);
  }, [autoHeight, getCount, maxLength, nonControlled, onChange, syncHeight]);
  useEffect4(() => {
    setCount(getCount(value ?? ""));
  }, [getCount, value]);
  useEffect4(() => {
    if (autoHeight && textareaRef.current !== null) {
      syncHeight(textareaRef.current);
    }
  }, [autoHeight, syncHeight]);
  const containerRef = useRef2(null);
  useFocusWithClick(containerRef, textareaRef);
  const textAreaId = useId3(props.id);
  const describedbyId = useId3();
  const labelledbyId = useId3();
  const classNames = useClassNames("charcoal-text-area-root", className);
  const showAssistiveText = assistiveText != null && assistiveText.length !== 0;
  return /* @__PURE__ */ jsxs6("div", { className: classNames, "aria-disabled": disabled, children: [
    /* @__PURE__ */ jsx17(FieldLabel_default, { htmlFor: textAreaId, id: labelledbyId, label, required, requiredText, subLabel, ...!showLabel ? visuallyHiddenProps : {} }),
    /* @__PURE__ */ jsxs6("div", { className: "charcoal-text-area-container", "aria-disabled": disabled === true ? "true" : void 0, "aria-invalid": invalid === true, ref: containerRef, style: {
      "--charcoal-text-area-rows": `${showCount ? rows + 1 : rows}`
    }, children: [
      /* @__PURE__ */ jsx17("textarea", { className: "charcoal-text-area-textarea", "aria-describedby": showAssistiveText ? describedbyId : void 0, "aria-invalid": invalid, "aria-labelledby": labelledbyId, id: textAreaId, maxLength, "data-no-bottom-padding": showCount, onChange: handleChange, ref: mergeRefs(forwardRef24, textareaRef), rows, value, disabled, ...props }),
      showCount && /* @__PURE__ */ jsx17("span", { className: "charcoal-text-area-counter", children: maxLength !== void 0 ? `${count}/${maxLength}` : count })
    ] }),
    showAssistiveText && /* @__PURE__ */ jsx17(AssistiveText, { "data-invalid": invalid === true, id: describedbyId, children: assistiveText })
  ] });
});
var TextArea_default = TextArea;

// src/components/Modal/index.tsx
import { useContext as useContext3, forwardRef as forwardRef16, memo as memo6 } from "react";
import * as React12 from "react";
import { Overlay } from "@react-aria/overlays";
import { animated, useTransition, easings } from "react-spring";
import { useObjectRef } from "@react-aria/utils";

// src/components/Modal/Dialog/index.tsx
import { forwardRef as forwardRef15 } from "react";
import { useDialog } from "@react-aria/dialog";

// src/_lib/useForwardedRef.tsx
import * as React9 from "react";
function useForwardedRef(ref) {
  const innerRef = React9.useRef(null);
  React9.useEffect(() => {
    if (!ref)
      return;
    if (typeof ref === "function") {
      ref(innerRef.current);
    } else {
      ref.current = innerRef.current;
    }
  });
  return innerRef;
}

// src/components/Modal/Dialog/index.tsx
import { jsx as jsx18 } from "react/jsx-runtime";
var Dialog = forwardRef15(function Dialog2({
  size,
  bottomSheet,
  className,
  ...props
}, forwardRef24) {
  const ref = useForwardedRef(forwardRef24);
  const {
    dialogProps
  } = useDialog({
    role: "dialog"
  }, ref);
  const classNames = useClassNames("charcoal-modal-dialog", className);
  return /* @__PURE__ */ jsx18("div", { className: classNames, role: dialogProps.role, "data-bottom-sheet": bottomSheet, tabIndex: dialogProps.tabIndex, "aria-labelledby": dialogProps["aria-labelledby"], onBlur: dialogProps.onBlur, "data-size": size, ref, ...props });
});

// src/components/Modal/ModalBackgroundContext.tsx
import * as React10 from "react";
var ModalBackgroundContext = React10.createContext(null);

// src/components/Modal/useCustomModalOverlay.tsx
import * as React11 from "react";
import { ariaHideOutside, useOverlay, useOverlayFocusContain } from "@react-aria/overlays";

// src/components/DropdownSelector/Popover/usePreventScroll.tsx
import { useEffect as useEffect6 } from "react";
function usePreventScroll(element, isOpen, useClip = false) {
  useEffect6(() => {
    if (isOpen && element) {
      const defaultPaddingRight = element.style.paddingRight;
      const defaultOverflow = element.style.overflow;
      element.style.paddingRight = `${window.innerWidth - element.clientWidth}px`;
      element.style.overflow = useClip ? "clip" : "hidden";
      return () => {
        element.style.paddingRight = defaultPaddingRight;
        element.style.overflow = defaultOverflow;
      };
    }
  }, [element, isOpen, useClip]);
}

// src/components/Modal/useCustomModalOverlay.tsx
function useCharcoalModalOverlay(props, state, ref) {
  const {
    overlayProps,
    underlayProps
  } = useOverlay({
    ...props,
    isOpen: state.isOpen,
    onClose: state.onClose,
    shouldCloseOnInteractOutside: () => false
  }, ref);
  usePreventScroll(typeof document !== "undefined" ? document.body : null, state.isOpen, props.overflowClip);
  useOverlayFocusContain();
  React11.useEffect(() => {
    if (state.isOpen && ref.current) {
      return ariaHideOutside([ref.current]);
    }
  }, [state.isOpen, ref]);
  return {
    modalProps: overlayProps,
    underlayProps
  };
}
function isWindowDefined() {
  return typeof window !== "undefined";
}
function useWindowWidth() {
  const [width, setWidth] = React11.useState(isWindowDefined() ? window.innerWidth : null);
  React11.useEffect(() => {
    const handleResize = () => {
      setWidth(window.innerWidth);
    };
    window.addEventListener("resize", handleResize);
    return () => {
      window.removeEventListener("resize", handleResize);
    };
  });
  return width;
}

// src/components/Modal/index.tsx
import { jsx as jsx19, jsxs as jsxs7 } from "react/jsx-runtime";
var DEFAULT_Z_INDEX = 10;
var Modal = forwardRef16(function ModalInner({
  children,
  zIndex = DEFAULT_Z_INDEX,
  portalContainer,
  ...props
}, external) {
  const {
    title,
    size = "M",
    bottomSheet = false,
    isDismissable,
    onClose,
    className,
    isOpen = false,
    closeButtonAriaLabel = "Close"
  } = props;
  const ref = useObjectRef(external);
  const {
    modalProps,
    underlayProps
  } = useCharcoalModalOverlay({
    ...props,
    isKeyboardDismissDisabled: isDismissable === void 0 || isDismissable === false
  }, {
    onClose,
    isOpen
  }, ref);
  const isMobile = (useWindowWidth() ?? Infinity) < 744;
  const transitionEnabled = isMobile && bottomSheet !== false;
  const showDismiss = !isMobile || bottomSheet !== true;
  const transition = useTransition(isOpen, {
    from: {
      transform: "translateY(100%)",
      backgroundColor: "rgba(0, 0, 0, 0)",
      overflow: "hidden"
    },
    enter: {
      transform: "translateY(0%)",
      backgroundColor: "rgba(0, 0, 0, 0.4)"
    },
    update: {
      overflow: "auto"
    },
    leave: {
      transform: "translateY(100%)",
      backgroundColor: "rgba(0, 0, 0, 0)",
      overflow: "hidden"
    },
    config: transitionEnabled ? {
      duration: 400,
      easing: easings.easeOutQuart
    } : {
      duration: 0
    }
  });
  const bgRef = React12.useRef(null);
  const handleClick = React12.useCallback((e) => {
    if (e.currentTarget === e.target) {
      onClose();
    }
  }, [onClose]);
  return transition(({
    backgroundColor,
    overflow,
    transform
  }, item) => item && /* @__PURE__ */ jsx19(Overlay, { portalContainer, children: /* @__PURE__ */ jsx19(animated.div, { className: "charcoal-modal-background", ref: bgRef, ...underlayProps, style: transitionEnabled ? {
    backgroundColor,
    overflow,
    zIndex
  } : {
    zIndex
  }, "data-bottom-sheet": bottomSheet, onClick: handleClick, children: /* @__PURE__ */ jsx19(ModalBackgroundContext.Provider, { value: bgRef.current, children: /* @__PURE__ */ jsx19(AnimatedDialog, { ref, ...modalProps, style: transitionEnabled ? {
    transform
  } : {}, size, bottomSheet, className, children: /* @__PURE__ */ jsxs7(ModalContext.Provider, { value: {
    titleProps: {},
    title,
    close: onClose,
    showDismiss,
    bottomSheet
  }, children: [
    children,
    isDismissable === true && /* @__PURE__ */ jsx19(ModalCloseButton, { "aria-label": closeButtonAriaLabel, onClick: onClose })
  ] }) }) }) }) }));
});
var AnimatedDialog = animated(Dialog);
var Modal_default = memo6(Modal);
var ModalContext = React12.createContext({
  titleProps: {},
  title: "",
  close: void 0,
  showDismiss: true,
  bottomSheet: false
});
function ModalCloseButton(props) {
  return /* @__PURE__ */ jsx19(IconButton_default, { className: "charcoal-modal-close-button", size: "S", icon: "24/Close", type: "button", ...props });
}

// src/components/Modal/ModalPlumbing.tsx
import { useContext as useContext4 } from "react";
import { jsx as jsx20 } from "react/jsx-runtime";
function ModalHeader() {
  const modalCtx = useContext4(ModalContext);
  return /* @__PURE__ */ jsx20("div", { className: "charcoal-modal-header-root", "data-bottom-sheet": modalCtx.bottomSheet, children: /* @__PURE__ */ jsx20("div", { className: "charcoal-modal-header-title", children: modalCtx.title }) });
}
var ModalAlign = createDivComponent("charcoal-modal-align");
var ModalBody = createDivComponent("charcoal-modal-body");
var ModalButtons = createDivComponent("charcoal-modal-buttons");

// src/components/LoadingSpinner/index.tsx
import { forwardRef as forwardRef17, useImperativeHandle, useRef as useRef5, memo as memo7 } from "react";
import { jsx as jsx21 } from "react/jsx-runtime";
var LoadingSpinner = forwardRef17(function LoadingSpinnerInner({
  size = 48,
  padding = 16,
  transparent = false,
  ...props
}, ref) {
  const classNames = useClassNames("charcoal-loading-spinner", props.className);
  return /* @__PURE__ */ jsx21("div", { role: "progressbar", style: {
    "--charcoal-loading-spinner-size": `${size}px`,
    "--charcoal-loading-spinner-padding": `${padding}px`
  }, "data-transparent": transparent, className: classNames, ref, children: /* @__PURE__ */ jsx21(LoadingSpinnerIcon, {}) });
});
var LoadingSpinner_default = memo7(LoadingSpinner);
var LoadingSpinnerIcon = forwardRef17(function LoadingSpinnerIcon2({
  once = false
}, ref) {
  const iconRef = useRef5(null);
  useImperativeHandle(ref, () => ({
    restart: () => {
      if (!iconRef.current) {
        return;
      }
      iconRef.current.dataset.resetAnimation = "true";
      void iconRef.current.offsetWidth;
      delete iconRef.current.dataset.resetAnimation;
    }
  }));
  return /* @__PURE__ */ jsx21("div", { role: "presentation", ref: iconRef, "data-once": once, className: "charcoal-loading-spinner-icon" });
});

// src/components/DropdownSelector/index.tsx
import { useState as useState5, useRef as useRef9, useMemo as useMemo8, useCallback as useCallback8 } from "react";

// src/components/DropdownSelector/DropdownPopover.tsx
import { useEffect as useEffect8, useRef as useRef7 } from "react";

// src/components/DropdownSelector/Popover/index.tsx
import { useContext as useContext5, useRef as useRef6 } from "react";
import { DismissButton, Overlay as Overlay2, usePopover } from "@react-aria/overlays";
import { jsx as jsx22, jsxs as jsxs8 } from "react/jsx-runtime";
var _empty = () => null;
function Popover(props) {
  const defaultPopoverRef = useRef6(null);
  const finalPopoverRef = props.popoverRef === void 0 ? defaultPopoverRef : props.popoverRef;
  const {
    popoverProps,
    underlayProps
  } = usePopover({
    triggerRef: props.triggerRef,
    popoverRef: finalPopoverRef,
    containerPadding: 16
  }, {
    close: props.onClose,
    isOpen: props.isOpen,
    // never used
    open: _empty,
    setOpen: _empty,
    toggle: _empty
  });
  const modalBackground = useContext5(ModalBackgroundContext);
  usePreventScroll(modalBackground, props.isOpen);
  if (!props.isOpen)
    return null;
  return /* @__PURE__ */ jsxs8(Overlay2, { portalContainer: document.body, children: [
    /* @__PURE__ */ jsx22("div", { ...underlayProps, style: {
      position: "fixed",
      zIndex: typeof popoverProps.style?.zIndex === "number" ? popoverProps.style.zIndex - 1 : 99999,
      inset: 0
    } }),
    /* @__PURE__ */ jsxs8("div", { ...popoverProps, ref: finalPopoverRef, className: "charcoal-popover", children: [
      /* @__PURE__ */ jsx22(DismissButton, { onDismiss: () => props.onClose() }),
      /* @__PURE__ */ jsx22("div", { tabIndex: 0, onFocus: props.onClose }),
      props.children,
      /* @__PURE__ */ jsx22("div", { tabIndex: 0, onFocus: props.onClose }),
      /* @__PURE__ */ jsx22(DismissButton, { onDismiss: () => props.onClose() })
    ] })
  ] });
}

// src/components/DropdownSelector/DropdownPopover.tsx
import { jsx as jsx23 } from "react/jsx-runtime";
function DropdownPopover({
  children,
  ...props
}) {
  const ref = useRef7(null);
  useEffect8(() => {
    if (props.isOpen && ref.current && props.triggerRef.current) {
      ref.current.style.width = `${props.triggerRef.current.clientWidth}px`;
    }
  }, [props.triggerRef, props.isOpen]);
  useEffect8(() => {
    if (props.isOpen) {
      if (props.value !== void 0 && props.value !== "") {
        const windowScrollY = window.scrollY;
        const windowScrollX = window.scrollX;
        const selectedElement = document.querySelector(`[data-key="${props.value.toString()}"]`);
        selectedElement?.focus();
        window.scrollTo(windowScrollX, windowScrollY);
      } else {
        const el = ref.current?.querySelector("[role='option']");
        if (el instanceof HTMLElement) {
          el.focus();
        }
      }
    }
  }, [props.value, props.isOpen]);
  return /* @__PURE__ */ jsx23(Popover, { isOpen: props.isOpen, onClose: props.onClose, popoverRef: ref, triggerRef: props.triggerRef, children });
}

// src/components/DropdownSelector/utils/findPreviewRecursive.tsx
import * as React13 from "react";
function findPreviewRecursive(children, value) {
  const childArray = React13.Children.toArray(children);
  for (let i = 0; i < childArray.length; i++) {
    const child = childArray[i];
    if (React13.isValidElement(child)) {
      if ("value" in child.props) {
        const childValue = child.props.value;
        if (childValue === value && "children" in child.props) {
          const children2 = child.props.children;
          return children2;
        }
      }
      if ("children" in child.props) {
        const children2 = findPreviewRecursive(child.props.children, value);
        if (children2 !== void 0) {
          return children2;
        }
      }
    }
  }
}

// src/components/DropdownSelector/MenuList/index.tsx
import { useMemo as useMemo7, useRef as useRef8 } from "react";

// src/components/DropdownSelector/MenuList/MenuListContext.ts
import { createContext as createContext5 } from "react";
var MenuListContext = createContext5({
  root: void 0,
  value: "",
  propsArray: [],
  setValue: (_v) => {
  }
});

// src/components/DropdownSelector/MenuList/internals/getValuesRecursive.tsx
import * as React14 from "react";
function getValuesRecursive(children) {
  const childArray = React14.Children.toArray(children);
  const propsArray = [];
  for (let i = 0; i < childArray.length; i++) {
    const child = childArray[i];
    if (React14.isValidElement(child)) {
      const props = child.props;
      if ("value" in props && typeof props.value === "string") {
        propsArray.push({
          disabled: props.disabled,
          value: props.value
        });
      }
      if ("children" in props && props.children) {
        propsArray.push(...getValuesRecursive(props.children));
      }
    }
  }
  return propsArray;
}

// src/components/DropdownSelector/MenuList/index.tsx
import { jsx as jsx24 } from "react/jsx-runtime";
function MenuList(props) {
  const root = useRef8(null);
  const propsArray = useMemo7(() => getValuesRecursive(props.children), [props.children]);
  return /* @__PURE__ */ jsx24("ul", { className: "charcoal-menu-list", ref: root, children: /* @__PURE__ */ jsx24(MenuListContext.Provider, { value: {
    value: props.value ?? "",
    root,
    propsArray,
    setValue: (v) => {
      props.onChange?.(v);
    }
  }, children: props.children }) });
}

// src/components/DropdownSelector/index.tsx
import { useVisuallyHidden as useVisuallyHidden3 } from "@react-aria/visually-hidden";
import { useId as useId4 } from "@react-aria/utils";
import { jsx as jsx25, jsxs as jsxs9 } from "react/jsx-runtime";
function DropdownSelector({
  onChange,
  showLabel = false,
  ...props
}) {
  const triggerRef = useRef9(null);
  const [isOpen, setIsOpen] = useState5(false);
  const preview = findPreviewRecursive(props.children, props.value);
  const isPlaceholder = useMemo8(() => props.placeholder !== void 0 && preview === void 0, [preview, props.placeholder]);
  const propsArray = getValuesRecursive(props.children);
  const {
    visuallyHiddenProps
  } = useVisuallyHidden3();
  const handleChange = useCallback8((e) => {
    onChange(e.target.value);
  }, [onChange]);
  const labelId = useId4();
  const describedbyId = useId4();
  const classNames = useClassNames("charcoal-dropdown-selector-root", props.className);
  return /* @__PURE__ */ jsxs9("div", { className: classNames, "aria-disabled": props.disabled, children: [
    /* @__PURE__ */ jsx25(FieldLabel_default, { id: labelId, label: props.label, required: props.required, requiredText: props.requiredText, subLabel: props.subLabel, ...!showLabel ? visuallyHiddenProps : {} }),
    /* @__PURE__ */ jsx25("div", { ...visuallyHiddenProps, "aria-hidden": "true", children: /* @__PURE__ */ jsx25("select", { name: props.name, value: props.value, onChange: handleChange, tabIndex: -1, children: propsArray.map((itemProps) => {
      return /* @__PURE__ */ jsx25("option", { value: itemProps.value, disabled: itemProps.disabled, children: itemProps.value }, itemProps.value);
    }) }) }),
    /* @__PURE__ */ jsxs9("button", { className: "charcoal-dropdown-selector-button", "aria-labelledby": labelId, "aria-invalid": props.invalid, "aria-describedby": props.assistiveText !== void 0 ? describedbyId : void 0, disabled: props.disabled, onClick: () => {
      if (props.disabled === true)
        return;
      setIsOpen(true);
    }, ref: triggerRef, type: "button", "data-active": isOpen, children: [
      /* @__PURE__ */ jsx25("span", { className: "charcoal-ui-dropdown-selector-text", "data-placeholder": isPlaceholder, children: isPlaceholder ? props.placeholder : preview }),
      /* @__PURE__ */ jsx25(Icon_default, { className: "charcoal-ui-dropdown-selector-icon", name: "16/Menu" })
    ] }),
    isOpen && /* @__PURE__ */ jsx25(DropdownPopover, { isOpen, onClose: () => setIsOpen(false), triggerRef, value: props.value, children: /* @__PURE__ */ jsx25(MenuList, { value: props.value, onChange: (v) => {
      onChange(v);
      setIsOpen(false);
    }, children: props.children }) }),
    props.assistiveText !== void 0 && /* @__PURE__ */ jsx25(AssistiveText, { "data-invalid": props.invalid === true, id: describedbyId, children: props.assistiveText })
  ] });
}

// src/components/DropdownSelector/MenuItem/index.tsx
import { forwardRef as forwardRef19 } from "react";

// src/components/DropdownSelector/ListItem/index.tsx
import { forwardRef as forwardRef18, useMemo as useMemo9 } from "react";
import { jsx as jsx26 } from "react/jsx-runtime";
var ListItem = forwardRef18(function ListItem2({
  as,
  className,
  ...props
}, ref) {
  const Component = useMemo9(() => as ?? "li", [as]);
  const classNames = useClassNames("charcoal-list-item", className);
  return /* @__PURE__ */ jsx26(Component, { className: classNames, ref, ...props });
});
var ListItem_default = ListItem;

// src/components/DropdownSelector/MenuItem/internals/useMenuItemHandleKeyDown.tsx
import { useCallback as useCallback9, useContext as useContext6 } from "react";

// src/components/DropdownSelector/MenuItem/internals/handleFocusByKeyBoard.tsx
function handleFocusByKeyBoard(element, parent) {
  const isScrollable = parent.scrollHeight > parent.clientHeight;
  if (isScrollable) {
    const rect = element.getBoundingClientRect();
    const parentRect = parent.getBoundingClientRect();
    if (rect.bottom > parentRect.bottom) {
      parent.scrollTo({
        top: parent.scrollTop + rect.bottom - parentRect.bottom
      });
    } else if (rect.top < parentRect.top) {
      parent.scrollTo({
        top: parent.scrollTop - (parentRect.top - rect.top)
      });
    }
  } else {
    scrollIfNeeded(element);
  }
}
function scrollIfNeeded(element) {
  const elementRect = element.getBoundingClientRect();
  const isVisible = elementRect.top >= 0 && elementRect.bottom <= (window.innerHeight || document.documentElement.clientHeight);
  if (!isVisible) {
    element.scrollIntoView({
      block: "nearest"
    });
  }
}

// src/components/DropdownSelector/MenuItem/internals/useMenuItemHandleKeyDown.tsx
function useMenuItemHandleKeyDown(value) {
  const {
    setValue,
    root,
    propsArray
  } = useContext6(MenuListContext);
  const setContextValue = useCallback9(() => {
    if (value !== void 0)
      setValue(value);
  }, [value, setValue]);
  const handleKeyDown = useCallback9((e) => {
    if (e.key === "Enter") {
      setContextValue();
    } else if (e.key === "ArrowUp" || e.key === "ArrowDown") {
      const isForward = e.key === "ArrowDown";
      e.preventDefault();
      if (!propsArray || value === void 0)
        return;
      const values = propsArray.map((props) => props.value).filter((v) => v);
      let index = values.indexOf(value);
      if (index === -1)
        return;
      for (let n = 0; n < values.length; n++) {
        const focusValue = isForward ? (
          // prev or last
          index + 1 >= values.length ? values[0] : values[index + 1]
        ) : (
          // next or first
          index - 1 < 0 ? values[values.length - 1] : values[index - 1]
        );
        const next = root?.current?.querySelector(`[data-key='${focusValue}']`);
        if (next instanceof HTMLElement) {
          if (next.ariaDisabled === "true") {
            index += isForward ? 1 : -1;
            continue;
          }
          next.focus({
            preventScroll: true
          });
          if (root?.current?.parentElement) {
            handleFocusByKeyBoard(next, root.current.parentElement);
          }
          break;
        }
      }
    }
  }, [setContextValue, propsArray, value, root]);
  return [handleKeyDown, setContextValue];
}

// src/components/DropdownSelector/MenuItem/index.tsx
import { jsx as jsx27 } from "react/jsx-runtime";
var MenuItem = forwardRef19(function MenuItem2({
  className,
  value,
  disabled,
  ...props
}, ref) {
  const [handleKeyDown, setContextValue] = useMenuItemHandleKeyDown(value);
  return /* @__PURE__ */ jsx27(ListItem_default, { ...props, ref, "data-key": value, onKeyDown: handleKeyDown, onClick: disabled === true ? void 0 : setContextValue, tabIndex: -1, "aria-disabled": disabled, role: "option", children: props.children });
});
var MenuItem_default = MenuItem;

// src/components/DropdownSelector/DropdownMenuItem/index.tsx
import { useContext as useContext7 } from "react";
import { jsx as jsx28, jsxs as jsxs10 } from "react/jsx-runtime";
function DropdownMenuItem(props) {
  const {
    value: ctxValue
  } = useContext7(MenuListContext);
  const isSelected = props.value === ctxValue;
  const {
    children,
    ...rest
  } = props;
  return /* @__PURE__ */ jsxs10(MenuItem_default, { ...rest, "aria-selected": isSelected, children: [
    isSelected && /* @__PURE__ */ jsx28(Icon_default, { className: "charcoal-dropdown-selector-menu-item-icon", name: "16/Check" }),
    /* @__PURE__ */ jsx28("span", { className: "charcoal-dropdown-selector-menu-item", "data-selected": isSelected, children: props.children })
  ] });
}

// src/components/DropdownSelector/MenuItemGroup/index.tsx
import { jsx as jsx29, jsxs as jsxs11 } from "react/jsx-runtime";
function MenuItemGroup(props) {
  return /* @__PURE__ */ jsxs11("li", { className: "charcoal-menu-item-group", role: "presentation", children: [
    /* @__PURE__ */ jsx29("span", { children: props.text }),
    /* @__PURE__ */ jsx29("ul", { role: "group", children: props.children })
  ] });
}

// src/components/SegmentedControl/index.tsx
import { forwardRef as forwardRef20, memo as memo8, useMemo as useMemo10, useRef as useRef10 } from "react";
import { useRadioGroupState } from "@react-stately/radio";
import { useRadio, useRadioGroup } from "@react-aria/radio";

// src/components/SegmentedControl/RadioGroupContext.tsx
import { createContext as createContext6, useContext as useContext8 } from "react";
import { jsx as jsx30 } from "react/jsx-runtime";
var RadioContext = createContext6(null);
var RadioProvider = ({
  value,
  children
}) => {
  return /* @__PURE__ */ jsx30(RadioContext.Provider, { value, children });
};
var useRadioContext = () => {
  const state = useContext8(RadioContext);
  if (state === null)
    throw new Error("`<RadioProvider>` is not likely mounted.");
  return state;
};

// src/components/SegmentedControl/index.tsx
import { jsx as jsx31, jsxs as jsxs12 } from "react/jsx-runtime";
var SegmentedControl = forwardRef20(function SegmentedControlInner(props, ref) {
  const className = useClassNames("charcoal-segmented-control", props.className);
  const ariaRadioGroupProps = useMemo10(() => ({
    ...props,
    isDisabled: props.disabled,
    isReadOnly: props.readonly,
    isRequired: props.required,
    "aria-label": props.name
  }), [props]);
  const state = useRadioGroupState(ariaRadioGroupProps);
  const {
    radioGroupProps
  } = useRadioGroup(ariaRadioGroupProps, state);
  const segmentedControlItems = useMemo10(() => {
    return props.data.map((d) => typeof d === "string" ? {
      value: d,
      label: d
    } : d);
  }, [props.data]);
  return /* @__PURE__ */ jsx31("div", { ref, ...radioGroupProps, className, children: /* @__PURE__ */ jsx31(RadioProvider, { value: state, children: segmentedControlItems.map((item) => /* @__PURE__ */ jsx31(Segmented, { value: item.value, disabled: item.disabled, children: item.label }, item.value)) }) });
});
var SegmentedControl_default = memo8(SegmentedControl);
var Segmented = (props) => {
  const state = useRadioContext();
  const ref = useRef10(null);
  const ariaRadioProps = useMemo10(() => ({
    value: props.value,
    isDisabled: props.disabled,
    children: props.children
  }), [props]);
  const {
    inputProps,
    isDisabled,
    isSelected
  } = useRadio(ariaRadioProps, state, ref);
  return /* @__PURE__ */ jsxs12("label", { className: "charcoal-segmented-control-radio__label", "aria-disabled": isDisabled || state.isReadOnly, "data-checked": isSelected, children: [
    /* @__PURE__ */ jsx31("input", { className: "charcoal-segmented-control-radio__input", ...inputProps, ref }),
    props.children
  ] });
};

// src/components/Checkbox/index.tsx
import { forwardRef as forwardRef22, memo as memo10 } from "react";
import { useId as useId5 } from "@react-aria/utils";

// src/components/Checkbox/CheckboxInput/index.tsx
import { forwardRef as forwardRef21, memo as memo9, useCallback as useCallback10 } from "react";
import { jsx as jsx32 } from "react/jsx-runtime";
var CheckboxInput = forwardRef21(function CheckboxInput2({
  onChange,
  checked,
  invalid,
  className,
  rounded,
  ...props
}, ref) {
  const handleChange = useCallback10((e) => {
    const el = e.currentTarget;
    onChange?.(el.checked);
  }, [onChange]);
  const classNames = useClassNames("charcoal-checkbox-input", className);
  return /* @__PURE__ */ jsx32("input", { className: classNames, ref, type: "checkbox", onChange: handleChange, "aria-invalid": invalid, checked, "data-rounded": rounded, ...props });
});
var CheckboxInput_default = memo9(CheckboxInput);

// src/components/Checkbox/CheckboxWithLabel.tsx
import React16 from "react";
import { jsx as jsx33, jsxs as jsxs13 } from "react/jsx-runtime";
var CheckboxWithLabel = React16.memo(function CheckboxWithLabel2({
  className,
  children,
  input,
  id,
  disabled
}) {
  const classNames = useClassNames("charcoal-checkbox__label", className);
  return /* @__PURE__ */ jsxs13("label", { htmlFor: id, "aria-disabled": disabled, className: classNames, children: [
    input,
    /* @__PURE__ */ jsx33("div", { className: "charcoal-checkbox__label_div", children })
  ] });
});

// src/components/Checkbox/index.tsx
import { jsx as jsx34 } from "react/jsx-runtime";
var Checkbox = forwardRef22(function Checkbox2({
  disabled,
  className,
  id,
  children,
  ...props
}, ref) {
  const htmlId = useId5(id);
  const noChildren = children === void 0;
  const input = /* @__PURE__ */ jsx34(CheckboxInput_default, { ...props, className: noChildren ? className : void 0, disabled, id: htmlId, ref });
  if (noChildren) {
    return input;
  }
  return /* @__PURE__ */ jsx34(CheckboxWithLabel, { className, disabled, id: htmlId, input, children });
});
var Checkbox_default = memo10(Checkbox);

// src/components/TagItem/index.tsx
import { forwardRef as forwardRef23, memo as memo11, useMemo as useMemo11 } from "react";
import { useObjectRef as useObjectRef2 } from "@react-aria/utils";
import { jsx as jsx35, jsxs as jsxs14 } from "react/jsx-runtime";
var TagItem = forwardRef23(function TagItemInner({
  component,
  label,
  translatedLabel,
  bgColor = "#7ACCB1",
  bgImage,
  size = "M",
  status = "default",
  ...props
}, _ref) {
  const ref = useObjectRef2(_ref);
  const hasTranslatedLabel = translatedLabel !== void 0 && translatedLabel.length > 0;
  const className = useClassNames("charcoal-tag-item", "charcoal-tag-item__bg", props.className);
  const bgVariant = bgImage !== void 0 && bgImage.length > 0 ? "image" : "color";
  const bg = bgVariant === "color" ? bgColor : `url(${bgImage ?? ""})`;
  const Component = useMemo11(() => component ?? "button", [component]);
  return /* @__PURE__ */ jsxs14(Component, { ...props, ref, className, "data-state": status, "data-bg-variant": bgVariant, "data-size": hasTranslatedLabel ? "M" : size, style: {
    "--charcoal-tag-item-bg": bg
  }, children: [
    /* @__PURE__ */ jsxs14("div", { className: "charcoal-tag-item__label", "data-has-translate": hasTranslatedLabel, children: [
      hasTranslatedLabel && /* @__PURE__ */ jsx35("span", { className: "charcoal-tag-item__label__translated", children: translatedLabel }),
      /* @__PURE__ */ jsx35("span", { className: "charcoal-tag-item__label__text", "data-has-translate": hasTranslatedLabel, children: label })
    ] }),
    status === "active" && /* @__PURE__ */ jsx35(Icon_default, { name: "16/Remove" })
  ] });
});
var TagItem_default = memo11(TagItem);
export {
  Button_default as Button,
  CharcoalProvider,
  Checkbox_default as Checkbox,
  Clickable_default as Clickable,
  DropdownMenuItem,
  DropdownSelector,
  Icon_default as Icon,
  IconButton_default as IconButton,
  LoadingSpinner_default as LoadingSpinner,
  LoadingSpinnerIcon,
  MenuItemGroup,
  Modal_default as Modal,
  ModalAlign,
  ModalBody,
  ModalButtons,
  ModalCloseButton,
  ModalHeader,
  MultiSelect_default as MultiSelect,
  MultiSelectGroup,
  OverlayProvider,
  Radio_default as Radio,
  RadioGroup,
  SSRProvider,
  SegmentedControl_default as SegmentedControl,
  SetThemeScript,
  Switch_default as Switch,
  TagItem_default as TagItem,
  TextArea_default as TextArea,
  TextField_default as TextField,
  getThemeSync,
  makeSetThemeScriptCode,
  prefersColorScheme,
  themeSelector,
  themeSetter,
  useLocalStorage,
  useMedia,
  useTheme,
  useThemeSetter
};
//# sourceMappingURL=index.esm.js.map